# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UsergroupArgs', 'Usergroup']

@pulumi.input_type
class UsergroupArgs:
    def __init__(__self__, *,
                 channels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 handle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Usergroup resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] channels: channel IDs for which the User Group uses as a default.
        :param pulumi.Input[str] description: a short description of the User Group.
        :param pulumi.Input[str] handle: a mention handle. Must be unique among channels, users
               and User Groups.
        :param pulumi.Input[str] name: a name for the User Group. Must be unique among User Groups.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: user IDs that represent the entire list of users for the
               User Group.
        """
        if channels is not None:
            pulumi.set(__self__, "channels", channels)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if handle is not None:
            pulumi.set(__self__, "handle", handle)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def channels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        channel IDs for which the User Group uses as a default.
        """
        return pulumi.get(self, "channels")

    @channels.setter
    def channels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "channels", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        a short description of the User Group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def handle(self) -> Optional[pulumi.Input[str]]:
        """
        a mention handle. Must be unique among channels, users
        and User Groups.
        """
        return pulumi.get(self, "handle")

    @handle.setter
    def handle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "handle", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        a name for the User Group. Must be unique among User Groups.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        user IDs that represent the entire list of users for the
        User Group.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _UsergroupState:
    def __init__(__self__, *,
                 channels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 handle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Usergroup resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] channels: channel IDs for which the User Group uses as a default.
        :param pulumi.Input[str] description: a short description of the User Group.
        :param pulumi.Input[str] handle: a mention handle. Must be unique among channels, users
               and User Groups.
        :param pulumi.Input[str] name: a name for the User Group. Must be unique among User Groups.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: user IDs that represent the entire list of users for the
               User Group.
        """
        if channels is not None:
            pulumi.set(__self__, "channels", channels)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if handle is not None:
            pulumi.set(__self__, "handle", handle)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def channels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        channel IDs for which the User Group uses as a default.
        """
        return pulumi.get(self, "channels")

    @channels.setter
    def channels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "channels", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        a short description of the User Group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def handle(self) -> Optional[pulumi.Input[str]]:
        """
        a mention handle. Must be unique among channels, users
        and User Groups.
        """
        return pulumi.get(self, "handle")

    @handle.setter
    def handle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "handle", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        a name for the User Group. Must be unique among User Groups.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        user IDs that represent the entire list of users for the
        User Group.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "users", value)


class Usergroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 channels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 handle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages a Slack User Group.

        ## Required scopes

        This resource requires the following scopes:

        - [usergroups:write](https://api.slack.com/scopes/usergroups:write)
        - [usergroups:read](https://api.slack.com/scopes/usergroups:read)

        The Slack API methods used by the resource are:

        - [usergroups.create](https://api.slack.com/methods/usergroups.create)
        - [usergroups.enable](https://api.slack.com/methods/usergroups.enable)
        - [usergroups.disable](https://api.slack.com/methods/usergroups.disable)
        - [usergroups.update](https://api.slack.com/methods/usergroups.update)
        - [usergroups.list](https://api.slack.com/methods/usergroups.list)
        - [usergroups.users.update](https://api.slack.com/methods/usergroups.users.update)

        If you get `missing_scope` errors while using this resource check the scopes against
        the documentation for the methods above.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_slack as slack

        my_group = slack.Usergroup("my_group",
            name="TestGroup",
            handle="test",
            description="Test user group",
            users=["USER00"],
            channels=["CHANNEL00"])
        ```

        Note that if a channel is removed from the `channels` list users are
        **not** removed from the channel. In order to keep the users in the
        groups and in the channel in sync set `permanent_users` in the channel:

        ```python
        import pulumi
        import pulumi_slack as slack

        my_group = slack.Usergroup("my_group",
            name="TestGroup",
            handle="test",
            description="Test user group",
            users=["USER00"])
        test = slack.Conversation("test",
            name="my-channel",
            topic="The topic for my channel",
            permanent_members=my_group.users,
            is_private=True)
        ```

        ## Import

        `slack_usergroup` can be imported using the ID of the group, e.g.

        ```sh
        $ pulumi import slack:index/usergroup:Usergroup my_group S022GE79E9G
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] channels: channel IDs for which the User Group uses as a default.
        :param pulumi.Input[str] description: a short description of the User Group.
        :param pulumi.Input[str] handle: a mention handle. Must be unique among channels, users
               and User Groups.
        :param pulumi.Input[str] name: a name for the User Group. Must be unique among User Groups.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: user IDs that represent the entire list of users for the
               User Group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UsergroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Slack User Group.

        ## Required scopes

        This resource requires the following scopes:

        - [usergroups:write](https://api.slack.com/scopes/usergroups:write)
        - [usergroups:read](https://api.slack.com/scopes/usergroups:read)

        The Slack API methods used by the resource are:

        - [usergroups.create](https://api.slack.com/methods/usergroups.create)
        - [usergroups.enable](https://api.slack.com/methods/usergroups.enable)
        - [usergroups.disable](https://api.slack.com/methods/usergroups.disable)
        - [usergroups.update](https://api.slack.com/methods/usergroups.update)
        - [usergroups.list](https://api.slack.com/methods/usergroups.list)
        - [usergroups.users.update](https://api.slack.com/methods/usergroups.users.update)

        If you get `missing_scope` errors while using this resource check the scopes against
        the documentation for the methods above.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_slack as slack

        my_group = slack.Usergroup("my_group",
            name="TestGroup",
            handle="test",
            description="Test user group",
            users=["USER00"],
            channels=["CHANNEL00"])
        ```

        Note that if a channel is removed from the `channels` list users are
        **not** removed from the channel. In order to keep the users in the
        groups and in the channel in sync set `permanent_users` in the channel:

        ```python
        import pulumi
        import pulumi_slack as slack

        my_group = slack.Usergroup("my_group",
            name="TestGroup",
            handle="test",
            description="Test user group",
            users=["USER00"])
        test = slack.Conversation("test",
            name="my-channel",
            topic="The topic for my channel",
            permanent_members=my_group.users,
            is_private=True)
        ```

        ## Import

        `slack_usergroup` can be imported using the ID of the group, e.g.

        ```sh
        $ pulumi import slack:index/usergroup:Usergroup my_group S022GE79E9G
        ```

        :param str resource_name: The name of the resource.
        :param UsergroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UsergroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 channels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 handle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UsergroupArgs.__new__(UsergroupArgs)

            __props__.__dict__["channels"] = channels
            __props__.__dict__["description"] = description
            __props__.__dict__["handle"] = handle
            __props__.__dict__["name"] = name
            __props__.__dict__["users"] = users
        super(Usergroup, __self__).__init__(
            'slack:index/usergroup:Usergroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            channels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            handle: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Usergroup':
        """
        Get an existing Usergroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] channels: channel IDs for which the User Group uses as a default.
        :param pulumi.Input[str] description: a short description of the User Group.
        :param pulumi.Input[str] handle: a mention handle. Must be unique among channels, users
               and User Groups.
        :param pulumi.Input[str] name: a name for the User Group. Must be unique among User Groups.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: user IDs that represent the entire list of users for the
               User Group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UsergroupState.__new__(_UsergroupState)

        __props__.__dict__["channels"] = channels
        __props__.__dict__["description"] = description
        __props__.__dict__["handle"] = handle
        __props__.__dict__["name"] = name
        __props__.__dict__["users"] = users
        return Usergroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def channels(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        channel IDs for which the User Group uses as a default.
        """
        return pulumi.get(self, "channels")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        a short description of the User Group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def handle(self) -> pulumi.Output[Optional[str]]:
        """
        a mention handle. Must be unique among channels, users
        and User Groups.
        """
        return pulumi.get(self, "handle")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        a name for the User Group. Must be unique among User Groups.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        user IDs that represent the entire list of users for the
        User Group.
        """
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUsergroupResult',
    'AwaitableGetUsergroupResult',
    'get_usergroup',
    'get_usergroup_output',
]

@pulumi.output_type
class GetUsergroupResult:
    """
    A collection of values returned by getUsergroup.
    """
    def __init__(__self__, channels=None, description=None, handle=None, id=None, name=None, usergroup_id=None, users=None):
        if channels and not isinstance(channels, list):
            raise TypeError("Expected argument 'channels' to be a list")
        pulumi.set(__self__, "channels", channels)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if handle and not isinstance(handle, str):
            raise TypeError("Expected argument 'handle' to be a str")
        pulumi.set(__self__, "handle", handle)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if usergroup_id and not isinstance(usergroup_id, str):
            raise TypeError("Expected argument 'usergroup_id' to be a str")
        pulumi.set(__self__, "usergroup_id", usergroup_id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def channels(self) -> Sequence[str]:
        """
        The channel IDs for which the User Group uses as a default.
        """
        return pulumi.get(self, "channels")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The short description of the User Group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def handle(self) -> str:
        """
        The mention handle.
        """
        return pulumi.get(self, "handle")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="usergroupId")
    def usergroup_id(self) -> Optional[str]:
        return pulumi.get(self, "usergroup_id")

    @property
    @pulumi.getter
    def users(self) -> Sequence[str]:
        """
        The user IDs that represent the entire list of users for the
        User Group.
        """
        return pulumi.get(self, "users")


class AwaitableGetUsergroupResult(GetUsergroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsergroupResult(
            channels=self.channels,
            description=self.description,
            handle=self.handle,
            id=self.id,
            name=self.name,
            usergroup_id=self.usergroup_id,
            users=self.users)


def get_usergroup(name: Optional[str] = None,
                  usergroup_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsergroupResult:
    """
    Use this data source to get information about a usergroups for use in other
    resources. The data source returns enabled groups only.

    ## Required scopes

    This resource requires the following scopes:

    - [usergroups:read](https://api.slack.com/scopes/usergroups:read)

    The Slack API methods used by the resource are:

    - [usergroups.list](https://api.slack.com/methods/usergroups.list)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    by_name = slack.get_usergroup(name="my-usergroup")
    by_id = slack.get_usergroup(usergroup_id="USERGROUP00")
    ```


    :param str name: The name of the usergroup
    :param str usergroup_id: The id of the usergroup
           
           The data source expects exactly one of these fields, you can't set both.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['usergroupId'] = usergroup_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('slack:index/getUsergroup:getUsergroup', __args__, opts=opts, typ=GetUsergroupResult).value

    return AwaitableGetUsergroupResult(
        channels=pulumi.get(__ret__, 'channels'),
        description=pulumi.get(__ret__, 'description'),
        handle=pulumi.get(__ret__, 'handle'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        usergroup_id=pulumi.get(__ret__, 'usergroup_id'),
        users=pulumi.get(__ret__, 'users'))
def get_usergroup_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                         usergroup_id: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUsergroupResult]:
    """
    Use this data source to get information about a usergroups for use in other
    resources. The data source returns enabled groups only.

    ## Required scopes

    This resource requires the following scopes:

    - [usergroups:read](https://api.slack.com/scopes/usergroups:read)

    The Slack API methods used by the resource are:

    - [usergroups.list](https://api.slack.com/methods/usergroups.list)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    by_name = slack.get_usergroup(name="my-usergroup")
    by_id = slack.get_usergroup(usergroup_id="USERGROUP00")
    ```


    :param str name: The name of the usergroup
    :param str usergroup_id: The id of the usergroup
           
           The data source expects exactly one of these fields, you can't set both.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['usergroupId'] = usergroup_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('slack:index/getUsergroup:getUsergroup', __args__, opts=opts, typ=GetUsergroupResult)
    return __ret__.apply(lambda __response__: GetUsergroupResult(
        channels=pulumi.get(__response__, 'channels'),
        description=pulumi.get(__response__, 'description'),
        handle=pulumi.get(__response__, 'handle'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        usergroup_id=pulumi.get(__response__, 'usergroup_id'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, email=None, id=None, name=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def email(self) -> Optional[str]:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            email=self.email,
            id=self.id,
            name=self.name)


def get_user(email: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Use this data source to get information about a user for use in other
    resources.

    ## Required scopes

    This resource requires the following scopes:

    - [users:read](https://api.slack.com/scopes/users:read)
    - [users:read.email](https://api.slack.com/scopes/users:read.email)

    The Slack API methods used by the resource are:

    - [users.lookupByEmail](https://api.slack.com/methods/users.lookupByEmail)
    - [users.list](https://api.slack.com/methods/users.list)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    by_name = slack.get_user(name="my-user")
    by_email = slack.get_user(email="my-user@example.com")
    ```


    :param str email: The email of the user
           
           The data source expects exactly one of these fields, you can't set both.
    :param str name: The name of the user
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('slack:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_user_output(email: Optional[pulumi.Input[Optional[str]]] = None,
                    name: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUserResult]:
    """
    Use this data source to get information about a user for use in other
    resources.

    ## Required scopes

    This resource requires the following scopes:

    - [users:read](https://api.slack.com/scopes/users:read)
    - [users:read.email](https://api.slack.com/scopes/users:read.email)

    The Slack API methods used by the resource are:

    - [users.lookupByEmail](https://api.slack.com/methods/users.lookupByEmail)
    - [users.list](https://api.slack.com/methods/users.list)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    by_name = slack.get_user(name="my-user")
    by_email = slack.get_user(email="my-user@example.com")
    ```


    :param str email: The email of the user
           
           The data source expects exactly one of these fields, you can't set both.
    :param str name: The name of the user
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('slack:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetConversationResult',
    'AwaitableGetConversationResult',
    'get_conversation',
    'get_conversation_output',
]

@pulumi.output_type
class GetConversationResult:
    """
    A collection of values returned by getConversation.
    """
    def __init__(__self__, channel_id=None, created=None, creator=None, id=None, is_archived=None, is_ext_shared=None, is_general=None, is_org_shared=None, is_private=None, is_shared=None, name=None, purpose=None, topic=None):
        if channel_id and not isinstance(channel_id, str):
            raise TypeError("Expected argument 'channel_id' to be a str")
        pulumi.set(__self__, "channel_id", channel_id)
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if creator and not isinstance(creator, str):
            raise TypeError("Expected argument 'creator' to be a str")
        pulumi.set(__self__, "creator", creator)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_archived and not isinstance(is_archived, bool):
            raise TypeError("Expected argument 'is_archived' to be a bool")
        pulumi.set(__self__, "is_archived", is_archived)
        if is_ext_shared and not isinstance(is_ext_shared, bool):
            raise TypeError("Expected argument 'is_ext_shared' to be a bool")
        pulumi.set(__self__, "is_ext_shared", is_ext_shared)
        if is_general and not isinstance(is_general, bool):
            raise TypeError("Expected argument 'is_general' to be a bool")
        pulumi.set(__self__, "is_general", is_general)
        if is_org_shared and not isinstance(is_org_shared, bool):
            raise TypeError("Expected argument 'is_org_shared' to be a bool")
        pulumi.set(__self__, "is_org_shared", is_org_shared)
        if is_private and not isinstance(is_private, bool):
            raise TypeError("Expected argument 'is_private' to be a bool")
        pulumi.set(__self__, "is_private", is_private)
        if is_shared and not isinstance(is_shared, bool):
            raise TypeError("Expected argument 'is_shared' to be a bool")
        pulumi.set(__self__, "is_shared", is_shared)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if purpose and not isinstance(purpose, str):
            raise TypeError("Expected argument 'purpose' to be a str")
        pulumi.set(__self__, "purpose", purpose)
        if topic and not isinstance(topic, str):
            raise TypeError("Expected argument 'topic' to be a str")
        pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[str]:
        return pulumi.get(self, "channel_id")

    @property
    @pulumi.getter
    def created(self) -> int:
        """
        is a unix timestamp.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter
    def creator(self) -> str:
        """
        is the user ID of the member that created this channel.
        """
        return pulumi.get(self, "creator")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isArchived")
    def is_archived(self) -> bool:
        """
        indicates a conversation is archived. Frozen in time.
        """
        return pulumi.get(self, "is_archived")

    @property
    @pulumi.getter(name="isExtShared")
    def is_ext_shared(self) -> bool:
        """
        represents this conversation as being part of a Shared Channel
        with a remote organization.
        """
        return pulumi.get(self, "is_ext_shared")

    @property
    @pulumi.getter(name="isGeneral")
    def is_general(self) -> bool:
        """
        will be true if this channel is the "general" channel that includes
        all regular team members.
        """
        return pulumi.get(self, "is_general")

    @property
    @pulumi.getter(name="isOrgShared")
    def is_org_shared(self) -> bool:
        """
        explains whether this shared channel is shared between Enterprise
        Grid workspaces within the same organization.
        """
        return pulumi.get(self, "is_org_shared")

    @property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> Optional[bool]:
        """
        means the conversation is privileged between two or more members.
        """
        return pulumi.get(self, "is_private")

    @property
    @pulumi.getter(name="isShared")
    def is_shared(self) -> bool:
        """
        means the conversation is in some way shared between multiple workspaces.
        """
        return pulumi.get(self, "is_shared")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        name of the public or private channel.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def purpose(self) -> str:
        """
        purpose of the channel.
        """
        return pulumi.get(self, "purpose")

    @property
    @pulumi.getter
    def topic(self) -> str:
        """
        topic for the channel.
        """
        return pulumi.get(self, "topic")


class AwaitableGetConversationResult(GetConversationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConversationResult(
            channel_id=self.channel_id,
            created=self.created,
            creator=self.creator,
            id=self.id,
            is_archived=self.is_archived,
            is_ext_shared=self.is_ext_shared,
            is_general=self.is_general,
            is_org_shared=self.is_org_shared,
            is_private=self.is_private,
            is_shared=self.is_shared,
            name=self.name,
            purpose=self.purpose,
            topic=self.topic)


def get_conversation(channel_id: Optional[str] = None,
                     is_private: Optional[bool] = None,
                     name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConversationResult:
    """
    Use this data source to get information about a Slack conversation for use in other
    resources.

    ## Required scopes

    This resource requires the following scopes:

    - [channels:read](https://api.slack.com/scopes/channels:read) (public channels)
    - [groups:read](https://api.slack.com/scopes/groups:read) (private channels)

    The Slack API methods used by the resource are:

    - [conversations.info](https://api.slack.com/methods/conversations.info)
    - [conversations.members](https://api.slack.com/methods/conversations.members)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    test = slack.get_conversation(channel_id="my-channel")
    test_name = slack.get_conversation(name="my-channel-name")
    ```


    :param str channel_id: The ID of the channel
    :param bool is_private: The conversation is privileged between two or more members
           
           Either `channel_id` or `name` must be provided. `is_private` only works in conjunction
           with `name`.
    :param str name: The name of the public or private channel
    """
    __args__ = dict()
    __args__['channelId'] = channel_id
    __args__['isPrivate'] = is_private
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('slack:index/getConversation:getConversation', __args__, opts=opts, typ=GetConversationResult).value

    return AwaitableGetConversationResult(
        channel_id=pulumi.get(__ret__, 'channel_id'),
        created=pulumi.get(__ret__, 'created'),
        creator=pulumi.get(__ret__, 'creator'),
        id=pulumi.get(__ret__, 'id'),
        is_archived=pulumi.get(__ret__, 'is_archived'),
        is_ext_shared=pulumi.get(__ret__, 'is_ext_shared'),
        is_general=pulumi.get(__ret__, 'is_general'),
        is_org_shared=pulumi.get(__ret__, 'is_org_shared'),
        is_private=pulumi.get(__ret__, 'is_private'),
        is_shared=pulumi.get(__ret__, 'is_shared'),
        name=pulumi.get(__ret__, 'name'),
        purpose=pulumi.get(__ret__, 'purpose'),
        topic=pulumi.get(__ret__, 'topic'))
def get_conversation_output(channel_id: Optional[pulumi.Input[Optional[str]]] = None,
                            is_private: Optional[pulumi.Input[Optional[bool]]] = None,
                            name: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetConversationResult]:
    """
    Use this data source to get information about a Slack conversation for use in other
    resources.

    ## Required scopes

    This resource requires the following scopes:

    - [channels:read](https://api.slack.com/scopes/channels:read) (public channels)
    - [groups:read](https://api.slack.com/scopes/groups:read) (private channels)

    The Slack API methods used by the resource are:

    - [conversations.info](https://api.slack.com/methods/conversations.info)
    - [conversations.members](https://api.slack.com/methods/conversations.members)

    If you get `missing_scope` errors while using this resource check the scopes against
    the documentation for the methods above.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_slack as slack

    test = slack.get_conversation(channel_id="my-channel")
    test_name = slack.get_conversation(name="my-channel-name")
    ```


    :param str channel_id: The ID of the channel
    :param bool is_private: The conversation is privileged between two or more members
           
           Either `channel_id` or `name` must be provided. `is_private` only works in conjunction
           with `name`.
    :param str name: The name of the public or private channel
    """
    __args__ = dict()
    __args__['channelId'] = channel_id
    __args__['isPrivate'] = is_private
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('slack:index/getConversation:getConversation', __args__, opts=opts, typ=GetConversationResult)
    return __ret__.apply(lambda __response__: GetConversationResult(
        channel_id=pulumi.get(__response__, 'channel_id'),
        created=pulumi.get(__response__, 'created'),
        creator=pulumi.get(__response__, 'creator'),
        id=pulumi.get(__response__, 'id'),
        is_archived=pulumi.get(__response__, 'is_archived'),
        is_ext_shared=pulumi.get(__response__, 'is_ext_shared'),
        is_general=pulumi.get(__response__, 'is_general'),
        is_org_shared=pulumi.get(__response__, 'is_org_shared'),
        is_private=pulumi.get(__response__, 'is_private'),
        is_shared=pulumi.get(__response__, 'is_shared'),
        name=pulumi.get(__response__, 'name'),
        purpose=pulumi.get(__response__, 'purpose'),
        topic=pulumi.get(__response__, 'topic')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConversationArgs', 'Conversation']

@pulumi.input_type
class ConversationArgs:
    def __init__(__self__, *,
                 is_private: pulumi.Input[bool],
                 action_on_destroy: Optional[pulumi.Input[str]] = None,
                 action_on_update_permanent_members: Optional[pulumi.Input[str]] = None,
                 adopt_existing_channel: Optional[pulumi.Input[bool]] = None,
                 is_archived: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 permanent_members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 purpose: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Conversation resource.
        :param pulumi.Input[bool] is_private: create a private channel instead of a public one.
        :param pulumi.Input[str] action_on_destroy: indicates whether the
               conversation should be archived or left behind on destroy. Valid values are
               `archive | none`. Note that when set to `none` the conversation will be left
               as it is  and as a result any subsequent runs of pulumi up with the same
               name  will fail.
        :param pulumi.Input[str] action_on_update_permanent_members: indicate
               whether the members should be kick of the channel when removed from
               `permanent_members`. When set to `none` the user are never kicked, this prevent
               a side effect on public channels where user that joined the channel are kicked.
        :param pulumi.Input[bool] is_archived: indicates a conversation is archived. Frozen in time.
        :param pulumi.Input[str] name: name of the public or private channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permanent_members: user IDs to add to the channel.
        :param pulumi.Input[str] purpose: purpose of the channel.
        :param pulumi.Input[str] topic: topic for the channel.
        """
        pulumi.set(__self__, "is_private", is_private)
        if action_on_destroy is not None:
            pulumi.set(__self__, "action_on_destroy", action_on_destroy)
        if action_on_update_permanent_members is not None:
            pulumi.set(__self__, "action_on_update_permanent_members", action_on_update_permanent_members)
        if adopt_existing_channel is not None:
            pulumi.set(__self__, "adopt_existing_channel", adopt_existing_channel)
        if is_archived is not None:
            pulumi.set(__self__, "is_archived", is_archived)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permanent_members is not None:
            pulumi.set(__self__, "permanent_members", permanent_members)
        if purpose is not None:
            pulumi.set(__self__, "purpose", purpose)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> pulumi.Input[bool]:
        """
        create a private channel instead of a public one.
        """
        return pulumi.get(self, "is_private")

    @is_private.setter
    def is_private(self, value: pulumi.Input[bool]):
        pulumi.set(self, "is_private", value)

    @property
    @pulumi.getter(name="actionOnDestroy")
    def action_on_destroy(self) -> Optional[pulumi.Input[str]]:
        """
        indicates whether the
        conversation should be archived or left behind on destroy. Valid values are
        `archive | none`. Note that when set to `none` the conversation will be left
        as it is  and as a result any subsequent runs of pulumi up with the same
        name  will fail.
        """
        return pulumi.get(self, "action_on_destroy")

    @action_on_destroy.setter
    def action_on_destroy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_on_destroy", value)

    @property
    @pulumi.getter(name="actionOnUpdatePermanentMembers")
    def action_on_update_permanent_members(self) -> Optional[pulumi.Input[str]]:
        """
        indicate
        whether the members should be kick of the channel when removed from
        `permanent_members`. When set to `none` the user are never kicked, this prevent
        a side effect on public channels where user that joined the channel are kicked.
        """
        return pulumi.get(self, "action_on_update_permanent_members")

    @action_on_update_permanent_members.setter
    def action_on_update_permanent_members(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_on_update_permanent_members", value)

    @property
    @pulumi.getter(name="adoptExistingChannel")
    def adopt_existing_channel(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "adopt_existing_channel")

    @adopt_existing_channel.setter
    def adopt_existing_channel(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "adopt_existing_channel", value)

    @property
    @pulumi.getter(name="isArchived")
    def is_archived(self) -> Optional[pulumi.Input[bool]]:
        """
        indicates a conversation is archived. Frozen in time.
        """
        return pulumi.get(self, "is_archived")

    @is_archived.setter
    def is_archived(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_archived", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        name of the public or private channel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permanentMembers")
    def permanent_members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        user IDs to add to the channel.
        """
        return pulumi.get(self, "permanent_members")

    @permanent_members.setter
    def permanent_members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "permanent_members", value)

    @property
    @pulumi.getter
    def purpose(self) -> Optional[pulumi.Input[str]]:
        """
        purpose of the channel.
        """
        return pulumi.get(self, "purpose")

    @purpose.setter
    def purpose(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "purpose", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        topic for the channel.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)


@pulumi.input_type
class _ConversationState:
    def __init__(__self__, *,
                 action_on_destroy: Optional[pulumi.Input[str]] = None,
                 action_on_update_permanent_members: Optional[pulumi.Input[str]] = None,
                 adopt_existing_channel: Optional[pulumi.Input[bool]] = None,
                 created: Optional[pulumi.Input[int]] = None,
                 creator: Optional[pulumi.Input[str]] = None,
                 is_archived: Optional[pulumi.Input[bool]] = None,
                 is_ext_shared: Optional[pulumi.Input[bool]] = None,
                 is_general: Optional[pulumi.Input[bool]] = None,
                 is_org_shared: Optional[pulumi.Input[bool]] = None,
                 is_private: Optional[pulumi.Input[bool]] = None,
                 is_shared: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 permanent_members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 purpose: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Conversation resources.
        :param pulumi.Input[str] action_on_destroy: indicates whether the
               conversation should be archived or left behind on destroy. Valid values are
               `archive | none`. Note that when set to `none` the conversation will be left
               as it is  and as a result any subsequent runs of pulumi up with the same
               name  will fail.
        :param pulumi.Input[str] action_on_update_permanent_members: indicate
               whether the members should be kick of the channel when removed from
               `permanent_members`. When set to `none` the user are never kicked, this prevent
               a side effect on public channels where user that joined the channel are kicked.
        :param pulumi.Input[int] created: is a unix timestamp.
        :param pulumi.Input[str] creator: is the user ID of the member that created this channel.
        :param pulumi.Input[bool] is_archived: indicates a conversation is archived. Frozen in time.
        :param pulumi.Input[bool] is_ext_shared: represents this conversation as being part of a Shared Channel
               with a remote organization.
        :param pulumi.Input[bool] is_general: will be true if this channel is the "general" channel that includes
               all regular team members.
        :param pulumi.Input[bool] is_org_shared: explains whether this shared channel is shared between Enterprise
               Grid workspaces within the same organization.
        :param pulumi.Input[bool] is_private: create a private channel instead of a public one.
        :param pulumi.Input[bool] is_shared: means the conversation is in some way shared between multiple workspaces.
        :param pulumi.Input[str] name: name of the public or private channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permanent_members: user IDs to add to the channel.
        :param pulumi.Input[str] purpose: purpose of the channel.
        :param pulumi.Input[str] topic: topic for the channel.
        """
        if action_on_destroy is not None:
            pulumi.set(__self__, "action_on_destroy", action_on_destroy)
        if action_on_update_permanent_members is not None:
            pulumi.set(__self__, "action_on_update_permanent_members", action_on_update_permanent_members)
        if adopt_existing_channel is not None:
            pulumi.set(__self__, "adopt_existing_channel", adopt_existing_channel)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if is_archived is not None:
            pulumi.set(__self__, "is_archived", is_archived)
        if is_ext_shared is not None:
            pulumi.set(__self__, "is_ext_shared", is_ext_shared)
        if is_general is not None:
            pulumi.set(__self__, "is_general", is_general)
        if is_org_shared is not None:
            pulumi.set(__self__, "is_org_shared", is_org_shared)
        if is_private is not None:
            pulumi.set(__self__, "is_private", is_private)
        if is_shared is not None:
            pulumi.set(__self__, "is_shared", is_shared)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permanent_members is not None:
            pulumi.set(__self__, "permanent_members", permanent_members)
        if purpose is not None:
            pulumi.set(__self__, "purpose", purpose)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="actionOnDestroy")
    def action_on_destroy(self) -> Optional[pulumi.Input[str]]:
        """
        indicates whether the
        conversation should be archived or left behind on destroy. Valid values are
        `archive | none`. Note that when set to `none` the conversation will be left
        as it is  and as a result any subsequent runs of pulumi up with the same
        name  will fail.
        """
        return pulumi.get(self, "action_on_destroy")

    @action_on_destroy.setter
    def action_on_destroy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_on_destroy", value)

    @property
    @pulumi.getter(name="actionOnUpdatePermanentMembers")
    def action_on_update_permanent_members(self) -> Optional[pulumi.Input[str]]:
        """
        indicate
        whether the members should be kick of the channel when removed from
        `permanent_members`. When set to `none` the user are never kicked, this prevent
        a side effect on public channels where user that joined the channel are kicked.
        """
        return pulumi.get(self, "action_on_update_permanent_members")

    @action_on_update_permanent_members.setter
    def action_on_update_permanent_members(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_on_update_permanent_members", value)

    @property
    @pulumi.getter(name="adoptExistingChannel")
    def adopt_existing_channel(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "adopt_existing_channel")

    @adopt_existing_channel.setter
    def adopt_existing_channel(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "adopt_existing_channel", value)

    @property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[int]]:
        """
        is a unix timestamp.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "created", value)

    @property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[str]]:
        """
        is the user ID of the member that created this channel.
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "creator", value)

    @property
    @pulumi.getter(name="isArchived")
    def is_archived(self) -> Optional[pulumi.Input[bool]]:
        """
        indicates a conversation is archived. Frozen in time.
        """
        return pulumi.get(self, "is_archived")

    @is_archived.setter
    def is_archived(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_archived", value)

    @property
    @pulumi.getter(name="isExtShared")
    def is_ext_shared(self) -> Optional[pulumi.Input[bool]]:
        """
        represents this conversation as being part of a Shared Channel
        with a remote organization.
        """
        return pulumi.get(self, "is_ext_shared")

    @is_ext_shared.setter
    def is_ext_shared(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_ext_shared", value)

    @property
    @pulumi.getter(name="isGeneral")
    def is_general(self) -> Optional[pulumi.Input[bool]]:
        """
        will be true if this channel is the "general" channel that includes
        all regular team members.
        """
        return pulumi.get(self, "is_general")

    @is_general.setter
    def is_general(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_general", value)

    @property
    @pulumi.getter(name="isOrgShared")
    def is_org_shared(self) -> Optional[pulumi.Input[bool]]:
        """
        explains whether this shared channel is shared between Enterprise
        Grid workspaces within the same organization.
        """
        return pulumi.get(self, "is_org_shared")

    @is_org_shared.setter
    def is_org_shared(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_org_shared", value)

    @property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> Optional[pulumi.Input[bool]]:
        """
        create a private channel instead of a public one.
        """
        return pulumi.get(self, "is_private")

    @is_private.setter
    def is_private(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_private", value)

    @property
    @pulumi.getter(name="isShared")
    def is_shared(self) -> Optional[pulumi.Input[bool]]:
        """
        means the conversation is in some way shared between multiple workspaces.
        """
        return pulumi.get(self, "is_shared")

    @is_shared.setter
    def is_shared(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_shared", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        name of the public or private channel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permanentMembers")
    def permanent_members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        user IDs to add to the channel.
        """
        return pulumi.get(self, "permanent_members")

    @permanent_members.setter
    def permanent_members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "permanent_members", value)

    @property
    @pulumi.getter
    def purpose(self) -> Optional[pulumi.Input[str]]:
        """
        purpose of the channel.
        """
        return pulumi.get(self, "purpose")

    @purpose.setter
    def purpose(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "purpose", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        topic for the channel.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)


class Conversation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_on_destroy: Optional[pulumi.Input[str]] = None,
                 action_on_update_permanent_members: Optional[pulumi.Input[str]] = None,
                 adopt_existing_channel: Optional[pulumi.Input[bool]] = None,
                 is_archived: Optional[pulumi.Input[bool]] = None,
                 is_private: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 permanent_members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 purpose: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Slack channel

        ## Required scopes

        This resource requires the following scopes:

        If using `bot` tokens:

        - [channels:read](https://api.slack.com/scopes/channels:read)
          (public channels)
        - [channels:manage](https://api.slack.com/scopes/channels:manage)
          (public channels)
        - [channels:join](https://api.slack.com/scopes/channels:join)
          (adopting existing public channels)
        - [groups:read](https://api.slack.com/scopes/groups:read)
          (private channels)
        - [groups:write](https://api.slack.com/scopes/groups:write)
          (private channels)

        If using `user` tokens:

        - [channels:read](https://api.slack.com/scopes/channels:read) (public channels)
        - [channels:write](https://api.slack.com/scopes/channels:manage) (public channels)
        - [groups:read](https://api.slack.com/scopes/groups:read) (private channels)
        - [groups:write](https://api.slack.com/scopes/groups:write) (private channels)

        The Slack API methods used by the resource are:

        - [conversations.create](https://api.slack.com/methods/conversations.create)
        - [conversations.join](https://api.slack.com/methods/conversations.join)
        - [conversations.setTopic](https://api.slack.com/methods/conversations.setTopic)
        - [conversations.setPurpose](https://api.slack.com/methods/conversations.setPurpose)
        - [conversations.info](https://api.slack.com/methods/conversations.info)
        - [conversations.members](https://api.slack.com/methods/conversations.members)
        - [conversations.kick](https://api.slack.com/methods/conversations.kick)
        - [conversations.invite](https://api.slack.com/methods/conversations.invite)
        - [conversations.rename](https://api.slack.com/methods/conversations.rename)
        - [conversations.archive](https://api.slack.com/methods/conversations.archive)
        - [conversations.unarchive](https://api.slack.com/methods/conversations.unarchive)

        If you get `missing_scope` errors while using this resource check the scopes against
        the documentation for the methods above.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_slack as slack

        test = slack.Conversation("test",
            name="my-channel",
            topic="The topic for my channel",
            permanent_members=[],
            is_private=True)
        ```

        ```python
        import pulumi
        import pulumi_slack as slack

        nonadmin = slack.Conversation("nonadmin",
            name="my-channel01",
            topic="The channel won't be archived on destroy",
            permanent_members=[],
            is_private=True,
            action_on_destroy="none")
        ```

        ```python
        import pulumi
        import pulumi_slack as slack

        adopted = slack.Conversation("adopted",
            name="my-channel02",
            topic="Adopt existing, don't kick members",
            permanent_members=[],
            adopt_existing_channel=True,
            action_on_update_permanent_members="none")
        ```

        ## Import

        `slack_conversation` can be imported using the ID of the conversation/channel, e.g.

        ```sh
        $ pulumi import slack:index/conversation:Conversation my_conversation C023X7QTFHQ
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_on_destroy: indicates whether the
               conversation should be archived or left behind on destroy. Valid values are
               `archive | none`. Note that when set to `none` the conversation will be left
               as it is  and as a result any subsequent runs of pulumi up with the same
               name  will fail.
        :param pulumi.Input[str] action_on_update_permanent_members: indicate
               whether the members should be kick of the channel when removed from
               `permanent_members`. When set to `none` the user are never kicked, this prevent
               a side effect on public channels where user that joined the channel are kicked.
        :param pulumi.Input[bool] is_archived: indicates a conversation is archived. Frozen in time.
        :param pulumi.Input[bool] is_private: create a private channel instead of a public one.
        :param pulumi.Input[str] name: name of the public or private channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permanent_members: user IDs to add to the channel.
        :param pulumi.Input[str] purpose: purpose of the channel.
        :param pulumi.Input[str] topic: topic for the channel.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConversationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Slack channel

        ## Required scopes

        This resource requires the following scopes:

        If using `bot` tokens:

        - [channels:read](https://api.slack.com/scopes/channels:read)
          (public channels)
        - [channels:manage](https://api.slack.com/scopes/channels:manage)
          (public channels)
        - [channels:join](https://api.slack.com/scopes/channels:join)
          (adopting existing public channels)
        - [groups:read](https://api.slack.com/scopes/groups:read)
          (private channels)
        - [groups:write](https://api.slack.com/scopes/groups:write)
          (private channels)

        If using `user` tokens:

        - [channels:read](https://api.slack.com/scopes/channels:read) (public channels)
        - [channels:write](https://api.slack.com/scopes/channels:manage) (public channels)
        - [groups:read](https://api.slack.com/scopes/groups:read) (private channels)
        - [groups:write](https://api.slack.com/scopes/groups:write) (private channels)

        The Slack API methods used by the resource are:

        - [conversations.create](https://api.slack.com/methods/conversations.create)
        - [conversations.join](https://api.slack.com/methods/conversations.join)
        - [conversations.setTopic](https://api.slack.com/methods/conversations.setTopic)
        - [conversations.setPurpose](https://api.slack.com/methods/conversations.setPurpose)
        - [conversations.info](https://api.slack.com/methods/conversations.info)
        - [conversations.members](https://api.slack.com/methods/conversations.members)
        - [conversations.kick](https://api.slack.com/methods/conversations.kick)
        - [conversations.invite](https://api.slack.com/methods/conversations.invite)
        - [conversations.rename](https://api.slack.com/methods/conversations.rename)
        - [conversations.archive](https://api.slack.com/methods/conversations.archive)
        - [conversations.unarchive](https://api.slack.com/methods/conversations.unarchive)

        If you get `missing_scope` errors while using this resource check the scopes against
        the documentation for the methods above.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_slack as slack

        test = slack.Conversation("test",
            name="my-channel",
            topic="The topic for my channel",
            permanent_members=[],
            is_private=True)
        ```

        ```python
        import pulumi
        import pulumi_slack as slack

        nonadmin = slack.Conversation("nonadmin",
            name="my-channel01",
            topic="The channel won't be archived on destroy",
            permanent_members=[],
            is_private=True,
            action_on_destroy="none")
        ```

        ```python
        import pulumi
        import pulumi_slack as slack

        adopted = slack.Conversation("adopted",
            name="my-channel02",
            topic="Adopt existing, don't kick members",
            permanent_members=[],
            adopt_existing_channel=True,
            action_on_update_permanent_members="none")
        ```

        ## Import

        `slack_conversation` can be imported using the ID of the conversation/channel, e.g.

        ```sh
        $ pulumi import slack:index/conversation:Conversation my_conversation C023X7QTFHQ
        ```

        :param str resource_name: The name of the resource.
        :param ConversationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConversationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_on_destroy: Optional[pulumi.Input[str]] = None,
                 action_on_update_permanent_members: Optional[pulumi.Input[str]] = None,
                 adopt_existing_channel: Optional[pulumi.Input[bool]] = None,
                 is_archived: Optional[pulumi.Input[bool]] = None,
                 is_private: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 permanent_members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 purpose: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConversationArgs.__new__(ConversationArgs)

            __props__.__dict__["action_on_destroy"] = action_on_destroy
            __props__.__dict__["action_on_update_permanent_members"] = action_on_update_permanent_members
            __props__.__dict__["adopt_existing_channel"] = adopt_existing_channel
            __props__.__dict__["is_archived"] = is_archived
            if is_private is None and not opts.urn:
                raise TypeError("Missing required property 'is_private'")
            __props__.__dict__["is_private"] = is_private
            __props__.__dict__["name"] = name
            __props__.__dict__["permanent_members"] = permanent_members
            __props__.__dict__["purpose"] = purpose
            __props__.__dict__["topic"] = topic
            __props__.__dict__["created"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["is_ext_shared"] = None
            __props__.__dict__["is_general"] = None
            __props__.__dict__["is_org_shared"] = None
            __props__.__dict__["is_shared"] = None
        super(Conversation, __self__).__init__(
            'slack:index/conversation:Conversation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_on_destroy: Optional[pulumi.Input[str]] = None,
            action_on_update_permanent_members: Optional[pulumi.Input[str]] = None,
            adopt_existing_channel: Optional[pulumi.Input[bool]] = None,
            created: Optional[pulumi.Input[int]] = None,
            creator: Optional[pulumi.Input[str]] = None,
            is_archived: Optional[pulumi.Input[bool]] = None,
            is_ext_shared: Optional[pulumi.Input[bool]] = None,
            is_general: Optional[pulumi.Input[bool]] = None,
            is_org_shared: Optional[pulumi.Input[bool]] = None,
            is_private: Optional[pulumi.Input[bool]] = None,
            is_shared: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            permanent_members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            purpose: Optional[pulumi.Input[str]] = None,
            topic: Optional[pulumi.Input[str]] = None) -> 'Conversation':
        """
        Get an existing Conversation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_on_destroy: indicates whether the
               conversation should be archived or left behind on destroy. Valid values are
               `archive | none`. Note that when set to `none` the conversation will be left
               as it is  and as a result any subsequent runs of pulumi up with the same
               name  will fail.
        :param pulumi.Input[str] action_on_update_permanent_members: indicate
               whether the members should be kick of the channel when removed from
               `permanent_members`. When set to `none` the user are never kicked, this prevent
               a side effect on public channels where user that joined the channel are kicked.
        :param pulumi.Input[int] created: is a unix timestamp.
        :param pulumi.Input[str] creator: is the user ID of the member that created this channel.
        :param pulumi.Input[bool] is_archived: indicates a conversation is archived. Frozen in time.
        :param pulumi.Input[bool] is_ext_shared: represents this conversation as being part of a Shared Channel
               with a remote organization.
        :param pulumi.Input[bool] is_general: will be true if this channel is the "general" channel that includes
               all regular team members.
        :param pulumi.Input[bool] is_org_shared: explains whether this shared channel is shared between Enterprise
               Grid workspaces within the same organization.
        :param pulumi.Input[bool] is_private: create a private channel instead of a public one.
        :param pulumi.Input[bool] is_shared: means the conversation is in some way shared between multiple workspaces.
        :param pulumi.Input[str] name: name of the public or private channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permanent_members: user IDs to add to the channel.
        :param pulumi.Input[str] purpose: purpose of the channel.
        :param pulumi.Input[str] topic: topic for the channel.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConversationState.__new__(_ConversationState)

        __props__.__dict__["action_on_destroy"] = action_on_destroy
        __props__.__dict__["action_on_update_permanent_members"] = action_on_update_permanent_members
        __props__.__dict__["adopt_existing_channel"] = adopt_existing_channel
        __props__.__dict__["created"] = created
        __props__.__dict__["creator"] = creator
        __props__.__dict__["is_archived"] = is_archived
        __props__.__dict__["is_ext_shared"] = is_ext_shared
        __props__.__dict__["is_general"] = is_general
        __props__.__dict__["is_org_shared"] = is_org_shared
        __props__.__dict__["is_private"] = is_private
        __props__.__dict__["is_shared"] = is_shared
        __props__.__dict__["name"] = name
        __props__.__dict__["permanent_members"] = permanent_members
        __props__.__dict__["purpose"] = purpose
        __props__.__dict__["topic"] = topic
        return Conversation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionOnDestroy")
    def action_on_destroy(self) -> pulumi.Output[Optional[str]]:
        """
        indicates whether the
        conversation should be archived or left behind on destroy. Valid values are
        `archive | none`. Note that when set to `none` the conversation will be left
        as it is  and as a result any subsequent runs of pulumi up with the same
        name  will fail.
        """
        return pulumi.get(self, "action_on_destroy")

    @property
    @pulumi.getter(name="actionOnUpdatePermanentMembers")
    def action_on_update_permanent_members(self) -> pulumi.Output[Optional[str]]:
        """
        indicate
        whether the members should be kick of the channel when removed from
        `permanent_members`. When set to `none` the user are never kicked, this prevent
        a side effect on public channels where user that joined the channel are kicked.
        """
        return pulumi.get(self, "action_on_update_permanent_members")

    @property
    @pulumi.getter(name="adoptExistingChannel")
    def adopt_existing_channel(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "adopt_existing_channel")

    @property
    @pulumi.getter
    def created(self) -> pulumi.Output[int]:
        """
        is a unix timestamp.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter
    def creator(self) -> pulumi.Output[str]:
        """
        is the user ID of the member that created this channel.
        """
        return pulumi.get(self, "creator")

    @property
    @pulumi.getter(name="isArchived")
    def is_archived(self) -> pulumi.Output[Optional[bool]]:
        """
        indicates a conversation is archived. Frozen in time.
        """
        return pulumi.get(self, "is_archived")

    @property
    @pulumi.getter(name="isExtShared")
    def is_ext_shared(self) -> pulumi.Output[bool]:
        """
        represents this conversation as being part of a Shared Channel
        with a remote organization.
        """
        return pulumi.get(self, "is_ext_shared")

    @property
    @pulumi.getter(name="isGeneral")
    def is_general(self) -> pulumi.Output[bool]:
        """
        will be true if this channel is the "general" channel that includes
        all regular team members.
        """
        return pulumi.get(self, "is_general")

    @property
    @pulumi.getter(name="isOrgShared")
    def is_org_shared(self) -> pulumi.Output[bool]:
        """
        explains whether this shared channel is shared between Enterprise
        Grid workspaces within the same organization.
        """
        return pulumi.get(self, "is_org_shared")

    @property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> pulumi.Output[bool]:
        """
        create a private channel instead of a public one.
        """
        return pulumi.get(self, "is_private")

    @property
    @pulumi.getter(name="isShared")
    def is_shared(self) -> pulumi.Output[bool]:
        """
        means the conversation is in some way shared between multiple workspaces.
        """
        return pulumi.get(self, "is_shared")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        name of the public or private channel.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="permanentMembers")
    def permanent_members(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        user IDs to add to the channel.
        """
        return pulumi.get(self, "permanent_members")

    @property
    @pulumi.getter
    def purpose(self) -> pulumi.Output[Optional[str]]:
        """
        purpose of the channel.
        """
        return pulumi.get(self, "purpose")

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Output[Optional[str]]:
        """
        topic for the channel.
        """
        return pulumi.get(self, "topic")

